.. image:: https://img.shields.io/pypi/v/framat.svg?style=flat
   :target: https://pypi.org/project/framat/
   :alt: Latest PyPI version

.. image:: https://readthedocs.org/projects/framat/badge/?version=latest
    :target: https://framat.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/badge/license-Apache%202-blue.svg
    :target: https://github.com/airinnova/framat/blob/master/LICENSE.txt
    :alt: License

.. image:: https://travis-ci.org/airinnova/framat.svg?branch=master
    :target: https://travis-ci.org/airinnova/framat
    :alt: Build status

.. image:: https://codecov.io/gh/airinnova/framat/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/airinnova/framat
    :alt: Coverage

|

.. image:: https://raw.githubusercontent.com/airinnova/framat/master/docs/source/_static/images/logo/logo.png
    :alt: FramAT
    :width: 100 px
    :scale: 100 %

*FramAT* (Frame Analysis Tool) is a tool for FEM beam analyses. Currently FramAT provides a full implementation of 3D Euler-Bernoulli beam theory which is also known as standard engineering beam theory.

.. image:: https://raw.githubusercontent.com/airinnova/framat/master/docs/source/_static/images/main.png
    :target: https://github.com/airinnova/framat
    :alt: Example
    :scale: 50 %

⚠ **Note** From version 0.3.2 to 0.4.0 interface for *FramAT* has been changed completely to a more user-friendly Python API. Please refer to the documentation for instructions and examples. Older development versions can still be found under `releases <https://github.com/airinnova/framat/releases>`_ (not recommended). The current interface is still under development.

How to get started
------------------

Please refer to the documentation for installation instructions and a user guide:

* https://framat.readthedocs.io/

Additional information for developers
-------------------------------------

*For developers*: Recommended packages may be installed with the `requirements.txt`.

.. code::

    pip install -r requirements.txt

License
-------

**License:** Apache-2.0
